@@ -15,15 +15,21 @@ def re_matcher(pattern):
 
 
 def simple_matcher(episode, extensions=[], zero=2):
-    return re_matcher(r"^.*{}.*({})$".format(leading_zero(episode, zero), "|".join(extensions)))
+    return re_matcher(r"^.*{}.*({})$".format(leading_zero(episode, zero),
+                                             "|".join(extensions)))
 
 
 def prefix_matcher(prefix, episode, extensions=[], zero=2):
-    return re_matcher(r"^.*{}{}.*({})$".format(prefix, leading_zero(episode, zero), "|".join(extensions)))
+    return re_matcher(r"^.*{}{}.*({})$".format(prefix,
+                                               leading_zero(episode, zero),
+                                               "|".join(extensions)))
 
 
 def prefix_suffix_matcher(prefix, suffix, episode, extensions=[], zero=2):
-    return re_matcher(r"^.*{}{}{}.*({})$".format(prefix, leading_zero(episode, zero), suffix, "|".join(extensions)))
+    return re_matcher(r"^.*{}{}{}.*({})$".format(prefix,
+                                                 leading_zero(episode, zero),
+                                                 suffix,
+                                                 "|".join(extensions)))
 
 
 def nth_matcher(episode):
@@ -63,10 +69,14 @@ def match(directory, matchers, limit=1):
 def match_episode(directory, episode, limit=1):
     matchers = []
     for p in config.PREFIXES:
-        for s in config.SURROUNDINGS:
-            for s in config.SURROUNDINGS:
+        for s1 in config.SURROUNDINGS:
+            for s2 in config.SURROUNDINGS:
                 for i in range(1, 3):
-                    matchers.append(prefix_suffix_matcher(p+s, s, episode, MOVIE_EXTENSIONS, i))
+                    matchers.append(prefix_suffix_matcher(
+                        p+s1,
+                        s2, episode,
+                        MOVIE_EXTENSIONS,
+                        i))
 
     for i in range(1, 3):
         matchers.append(simple_matcher(episode, MOVIE_EXTENSIONS, i))
@@ -78,10 +88,15 @@ def match_episode(directory, episode, limit=1):
 def match_subs(directory, episode, limit=1):
     matchers = []
     for p in config.PREFIXES:
-        for s in config.SURROUNDINGS:
-            for s in config.SURROUNDINGS:
+        for s1 in config.SURROUNDINGS:
+            for s2 in config.SURROUNDINGS:
                 for i in range(1, 3):
-                    matchers.append(prefix_suffix_matcher(p, s, episode, SUB_EXTENSIONS, i))
+                    matchers.append(prefix_suffix_matcher(
+                        p+s1,
+                        s2,
+                        episode,
+                        SUB_EXTENSIONS,
+                        i))
 
     matchers.append(simple_matcher(episode, SUB_EXTENSIONS))
     matchers.append(nth_matcher(episode))
